#
# spec file for package gstreamer-rtsp-server
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name gst-rtsp-server
Name:           gstreamer-rtsp-server
Version:        1.12.5
Release:        lp151.3.3.1
Summary:        GStreamer-based RTSP server library
License:        LGPL-2.0-or-later
Group:          Productivity/Multimedia/Other
URL:            http://gstreamer.freedesktop.org/
Source0:        https://gstreamer.freedesktop.org/src/gst-rtsp-server/%{_name}-%{version}.tar.xz
Source99:       gstreamer-rtsp-server-rpmlintrc
Patch0:         gst-rtsp-Fix-NULL-pointer.patch

BuildRequires:  gstreamer-plugins-good >= 1.10.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.31.1
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.12.0
BuildRequires:  pkgconfig(gstreamer-plugins-bad-1.0) >= 1.12.0
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= 1.12.0

%description
A library on top of GStreamer for building an RTSP server.

%package  -n libgstrtspserver-1_0-0
Summary:        GStreamer-based RTSP server library
Group:          System/Libraries

%description  -n libgstrtspserver-1_0-0
Library on top of GStreamer for building an RTSP server - Library files.

%package  -n typelib-1_0-GstRtspServer-1_0
Summary:        Introspection bindings for the GStreamer-based RTSP server library
Group:          System/Libraries

%description  -n typelib-1_0-GstRtspServer-1_0
Introspection bindings for the GStreamer library for building an RTSP server.

%package devel
Summary:        Development files for the GStreamer-based RTSP server library
Group:          Development/Languages/C and C++
Requires:       libgstrtspserver-1_0-0 = %{version}
Requires:       typelib-1_0-GstRtspServer-1_0 = %{version}
Provides:       gst-rtsp-server-devel = %{version}
Obsoletes:      gst-rtsp-server-devel < %{version}

%description devel
Development files for the GStreamer library for building an RTSP server.

%prep
%autosetup -n %{_name}-%{version} -p1

%build
%configure
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libgstrtspserver-1_0-0 -p /sbin/ldconfig
%postun -n libgstrtspserver-1_0-0 -p /sbin/ldconfig

%files -n libgstrtspserver-1_0-0
%license COPYING
%{_libdir}/libgstrtspserver-1.0.so.*

%files -n typelib-1_0-GstRtspServer-1_0
%{_libdir}/girepository-1.0/GstRtspServer-1.0.typelib

%files devel
%doc ChangeLog README
%{_datadir}/gir-1.0/GstRtspServer-1.0.gir
%{_includedir}/gstreamer-1.0/gst/rtsp-server/
%{_libdir}/libgstrtspserver-1.0.so
%{_libdir}/gstreamer-1.0/libgstrtspclientsink.so
%{_libdir}/pkgconfig/gstreamer-rtsp-server-1.0.pc

%changelog
* Mon Apr 13 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add gst-rtsp-Fix-NULL-pointer.patch: rtsp-auth: Fix NULL pointer
  dereference when handling an invalid basic Authorization header
  This fixes CVE-2020-6095 and TALOS-2020-1018 (boo#1168026).
* Fri Mar 30 2018 bjorn.lie@gmail.com
- Update to version 1.12.5:
  + Bugs fixed: bgo#789646, bgo#791743.
- Drop upstream fixed patches:
  + gst-rtsp-server-add-annotations-and-API-guards.patch.
  + gst-rtsp-server-gst_rtsp_context_get_current.patch.
  + gst-rtsp-server-rtsp-client-add-type-annotations.patch.
  + gst-rtsp-server-Set-udpsink_out-ttl-mc-property.patch.
* Mon Mar 26 2018 dimstar@opensuse.org
- Drop pkgconfig(libcgroup) BuildRequires: libcgroup's
  functionality is largely deprecated by systemd and the two
  actually clash in some ways which cause bug reports.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Feb 12 2018 bjorn.lie@gmail.com
- Add upstream bug fix patches:
  + gst-rtsp-server-rtsp-client-add-type-annotations.patch.
  + gst-rtsp-server-gst_rtsp_context_get_current.patch.
  + gst-rtsp-server-add-annotations-and-API-guards.patch.
* Tue Jan  9 2018 zaitor@opensuse.org
- Add gst-rtsp-server-Set-udpsink_out-ttl-mc-property.patch: rtsp:
  Set udpsink_out ttl-mc property on creation (bgo#791743).
- Clean up spec, silence some rpmlint warnings.
- Drop explicit libgstrtspserver-1_0-0 and
  typelib-1_0-GstRtspServer-1_0 Obsoletes and Provides: Not needed
  and only leads to a rpmlint warning.
- Add gstreamer-rtsp-server-rpmlintrc: Filter out bogus warning
  about missing dependencies in devel package.
* Mon Dec 11 2017 zaitor@opensuse.org
- Update to version 1.12.4:
  + Bugs fixed: bgo#789646, bgo#769521.
* Mon Sep 18 2017 zaitor@opensuse.org
- Update to version 1.12.3:
  + Bugs fixed: bgo#784094, bgo#786457.
* Fri Jul 14 2017 zaitor@opensuse.org
- Update to version 1.12.2:
  + No changes, stable version bump only.
* Wed Jun 21 2017 zaitor@opensuse.org
- Update to version 1.12.1:
  + No changes, stable version bump only.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 1.12.0:
  + No changes, stable version bump only.
- Changes from version 1.11.91:
  + gi: Fix some annotations and docstrings.
  + Automatic update of common submodule.
- Changes from version 1.11.90:
  + examples: make test-launch pipeline shared by default as well.
  + gstreamer-rtsp-server: Add both srcdir and builddir to the
    include path.
* Sat Feb 25 2017 zaitor@opensuse.org
- Update to version 1.11.2:
  + Meson build fixes.
  + Minor changes and fixes.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.11.1:
  + Bugs fixed: bgo#758062, bgo#771830, bgo#774173, bgo#774640,
    bgo#776867, bgo#777037, bgo#774416.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.10.4:
  + Minor tweaks and fixes.
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 1.10.3:
  + Bugs fixed: bgo#755329, bgo#776343, bgo#776345.
* Sun Jan  1 2017 jengelh@inai.de
- Summary updates.
* Sat Dec  3 2016 zaitor@opensuse.org
- Update to version 1.10.2:
  + Bugs fixed: bgo#765673, bgo#770239.
* Sun Nov 27 2016 zaitor@opensuse.org
- Update to version 1.10.1:
  + Meson update.
- Changes from version 1.10.0:
  + Bugs fixed: bgo#771983, bgo#772478, bgo#773640.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 1.8.3 (boo#996937):
  + g-i: pass compiler env to g-ir-scanner.
- Changes from version 1.8.2:
  + rtsp-session: RFC2326 does not allow a space between ; and
    timeout in the Session header.
  + rtsp-stream:
  - Fix crash on cleanup with shared media and multiple udpsrc.
  - Always bind to ANY when address is a multicast address and
    not only on Windows.
- Rename package to gstreamer-rtsp-server. Align with the other
  gstreamer packages. Also obsolete and provide the previous ones
  to ease updates.
* Wed Jun 15 2016 zaitor@opensuse.org
- Update to version 1.8.1:
  + bgo#764744: Crashes when multiple udpsrc are created for each
    client on a shared media, misses tracking and cleanup.
  + bgo#766619: Space between ; and timeout= in session header is
    not RFC2326 compliant.
* Thu Apr 21 2016 zaitor@opensuse.org
- Update to version 1.8.1:
  + No changes, version bump only.
* Sat Mar 26 2016 zaitor@opensuse.org
- Update to version 1.8.0:
  + Hardware-accelerated zero-copy video decoding on Android
  + New video capture source for Android using the
    android.hardware.Camera API.
  + Windows Media reverse playback support (ASF/WMV/WMA).
  + New tracing system provides support for more sophisticated
    debugging tools.
  + New high-level GstPlayer playback convenience API.
  + Initial support for the new Vulkan API, see Matthew Waters'
    blog post for more details.
  + Improved Opus audio codec support: Support for more than two
    channels; MPEG-TS demuxer/muxer can now handle Opus;
    sample-accurate encoding/decoding/transmuxing with Ogg,
    Matroska, ISOBMFF (Quicktime/MP4), and MPEG-TS as container;
    new codec utility functions for Opus header and caps handling
    in pbutils library. The Opus encoder/decoder elements were
    also moved to gst-plugins-base (from -bad), and the opus RTP
    depayloader/payloader to -good.
  + GStreamer VAAPI module now released and maintained as part of
    the GStreamer project.
  + Asset proxy support in the GStreamer Editing Services.
  + Bugs fixed: bgo#740509.
* Tue Dec 15 2015 zaitor@opensuse.org
- Update to version 1.6.2:
  + rtsp-server: Change the logic so we don't pop a NULL context.
* Sun Nov  1 2015 zaitor@opensuse.org
- Update to version 1.6.1:
  + gst-rtsp-server: Retain reference to rtsp-media when preparing.
  + rtsp-stream: GstBin leak in udp-mcast case.
- Changes from version 1.6.0:
  + For changelog, see mainpackage changes, everything is condensed
    there.
- Drop grs-rtsp-fix-double-unlock-in_get_buffer_size.patch: Fixed
  upstream.
* Wed Aug  5 2015 zaitor@opensuse.org
- Add grs-rtsp-fix-double-unlock-in_get_buffer_size.patch: Fixes an
  abort when calling gst_rtsp_media_get_buffer_size() because of
  double g_mutex_unlock () usage (bgo#745434).
* Fri Dec 26 2014 zaitor@opensuse.org
- Update to version 1.4.5:
  + rtsp-stream: leaks srtp decoder when leaving rtpbin
    (bgo#739481).
* Fri Nov 14 2014 zaitor@opensuse.org
- Update to version 1.4.4:
  + rtsp-client: mikey memory leaks (bgo#739383).
- Changes from version 1.4.3:
  + No changes.
- Changes from version 1.4.2:
  + rtsp-media: Make sure that sequence numbers are monotonic after
    pause (bgo#736017).
  + rtsp-client: Protect saved clients watch with a mutex
    (bgo#735570).
* Thu Aug 28 2014 zaitor@opensuse.org
- Update to version 1.4.1:
  + RTSP PLAY with specified range replies with wrong range
    (bgo#732644).
* Fri Mar 14 2014 zaitor@opensuse.org
- Initial packaging, version 1.4.0.
